@@ -1,10 +1,10 @@
-package App::Software::License; # git description: v0.02-14-g2727dfe
+package App::Software::License; # git description: v0.03-7-gba62de5
 # ABSTRACT: Command-line interface to Software::License
+# KEYWORDS: license licence LICENSE generate distribution build tool
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Moose;
-use MooseX::Types::Moose qw/Str Num/;
 use File::HomeDir;
 use File::Spec::Functions qw/catfile/;
 use Module::Runtime qw/use_module/;
@@ -25,7 +25,7 @@ with qw/MooseX::Getopt MooseX::SimpleConfig/;
 #pod
 #pod All the attributes documented below are available as command-line options
 #pod through L<MooseX::Getopt> and can also be configured in
-#pod L<$HOME/.software_license.conf> though L<MooseX::SimpleConfig>.
+#pod F<$HOME/.software_license.conf> though L<MooseX::SimpleConfig>.
 #pod
 #pod =cut
 
@@ -37,7 +37,7 @@ with qw/MooseX::Getopt MooseX::SimpleConfig/;
 
 has holder => (
     is       => 'ro',
-    isa      => Str,
+    isa      => 'Str',
     required => 1,
 );
 
@@ -49,7 +49,7 @@ has holder => (
 
 has year => (
     is       => 'ro',
-    isa      => Num,
+    isa      => 'Num',
 );
 
 #pod =attr license
@@ -61,7 +61,7 @@ has year => (
 
 has license => (
     is      => 'ro',
-    isa     => Str,
+    isa     => 'Str',
     default => 'Perl_5',
 );
 
@@ -104,7 +104,7 @@ has license => (
 
 has type => (
     is      => 'ro',
-    isa     => Str,
+    isa     => 'Str',
     default => 'notice',
 );
 
@@ -134,8 +134,10 @@ sub _build__software_license {
     });
 }
 
-override BUILDARGS => sub {
-    my $args = super;
+around BUILDARGS => sub {
+    my $orig = shift;
+    my $self = shift;
+    my $args = $self->$orig(@_);
     $args->{license} = $args->{extra_argv}->[0]
         if @{ $args->{extra_argv} };
     return $args;
@@ -170,7 +172,7 @@ App::Software::License - Command-line interface to Software::License
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -183,7 +185,7 @@ used to easily produce license notices to be included in other documents.
 
 All the attributes documented below are available as command-line options
 through L<MooseX::Getopt> and can also be configured in
-L<$HOME/.software_license.conf> though L<MooseX::SimpleConfig>.
+F<$HOME/.software_license.conf> though L<MooseX::SimpleConfig>.
 
 =head1 ATTRIBUTES
 
